@@ -43,12 +43,13 @@ class Cookbook(object):
     Example::
 
       from frycook import Cookbook
-      from recipes import AwesomeRecipe, WayCoolRecipe
 
-      class MyOwnCookbook(Cookbook):
+      from recipes import RecipeNginx
+      from recipes import RecipeExampleCom
 
-          recipe_list = [AwesomeRecipe,
-                         WayCoolRecipe]
+      class CookbookWeb(Cookbook):
+          recipe_list = [RecipeNginx,
+                         RecipeExampleCom]
 
     All cookbook files should live in a single cookbooks package.  The
     __init__.py file for this package should import all cookbooks and have a
@@ -63,11 +64,11 @@ class Cookbook(object):
       cookbooks = {
           'base': CookbookBase,
           'web': CookbookWeb
-      }
+          }
     '''
     recipe_list = []
 
-    def __init__(self, settings, environment):
+    def __init__(self, settings, environment, ok_to_be_rude):
         '''
         Initialize the cookbook object with the settings and environment
         dictionaries.
@@ -79,10 +80,15 @@ class Cookbook(object):
         @type environment: dict
 
         @param environment: metadata dictionary
+
+        @type ok_to_be_rude: boolean
+
+        @param ok_to_be_rude: is it ok to interrupt your users?
         '''
         self.recipes = []
+        self.ok_to_be_rude = ok_to_be_rude
         for recipe in self.recipe_list:
-            self.recipes.append(recipe(settings, environment))
+            self.recipes.append(recipe(settings, environment, ok_to_be_rude))
 
     #######################
     ######## APPLY ########
