@@ -46,16 +46,14 @@ could cause undesired configuration changes or expensive operations that you
 don't want to happen every time.  These functions are a huge aid in writing
 idempotent recipes and cookbooks.
 
-apply
-=====
+rudeness
+========
 
-This is where you apply a recipe to a server.  There are two class methods that
-get called during the apply process, and possibly two messages that get
-displayed.  Generally you'll just override the apply method and sometimes add
-pre_apply or post_apply messages.  If you override pre_apply_checks, remember
-to call the base class method.  Here's the order that things happen in:
-
-pre_apply_message -> pre_apply_checks() -> apply() -> post_apply_message
+Another thing to keep in mind is that some actions performed in recipes can
+affect the end users of the systems, in effect being rude to them.  This might
+cause an outage or otherwise mess them up.  The recipe class keeps track of
+whether or not this is ok in its 'ok_to_be_rude' variable so you can know what
+actions are acceptable.  Consult this before doing rude things.
 
 file set copying
 ================
@@ -72,6 +70,17 @@ The Recipe class also defines some helper functions for working with git repos.
 You can checkout a git repo onto the remote machine, or check it out locally
 and copy it to the remote machine if you don't want to setup the remote machine
 to be able to do checkouts.
+
+apply process
+=============
+
+This is where you apply a recipe to a server.  There are two class methods that
+get called during the apply process, and possibly two messages that get
+displayed.  Generally you'll just override the apply method and sometimes add
+pre_apply or post_apply messages.  If you override pre_apply_checks, remember
+to call the base class method.  Here's the order that things happen in:
+
+pre_apply_message -> pre_apply_checks() -> apply() -> post_apply_message
 '''
 import os
 import os.path
@@ -187,15 +196,16 @@ class Recipe(object):
     the framework for recipes and some helper functions.  By itself it doesn't
     do much.
 
-    Here is an example that implements a basic recipe to push a package
-    fileset::
+    Here is an example that implements a basic recipe to make sure a package is
+    installed::
+
+      import cuisine
 
       from frycook import Recipe
 
-      class MyOwnRecipe(Recipe):
-
+      class RecipeFail2ban(Recipe):
           def apply(self, computer):
-              self.push_package_file_set('my_own', computer)
+              cuisine.package_ensure('fail2ban')
 
     All recipe files should live in a single recipes package.  The __init__.py
     file for this package should import all recipes and have a list of them so
@@ -203,20 +213,28 @@ class Recipe(object):
 
     Example::
 
+      from fail2ban import RecipeFail2ban
       from hosts import RecipeHosts
       from nginx import RecipeNginx
-      from root import RecipeRootUser
+      from postfix import RecipePostfix
+      from root_user import RecipeRootUser
       from example_com import RecipeExampleCom
+      from shorewall import RecipeShorewall
+      from ssh import RecipeSSH
 
       recipes = {
+          'fail2ban': RecipeFail2ban,
           'hosts': RecipeHosts,
           'nginx': RecipeNginx,
-          'root': RecipeRootUser,
-          'example_com': RecipeExacmpleCom
-      }
+          'postfix': RecipePostfix,
+          'root_user': RecipeRootUser,
+          'example_com': RecipeExampleCom,
+          'shorewall': RecipeShorewall,
+          'ssh': RecipeSSH
+          }
     '''
 
-    def __init__(self, settings, environment):
+    def __init__(self, settings, environment, ok_to_be_rude):
         '''
         Initialize the recipe object with the settings and environment
         dictionaries.
@@ -228,9 +246,14 @@ class Recipe(object):
         @type environment: dict
 
         @param environment: metadata dictionary
+
+        @type ok_to_be_rude: boolean
+
+        @param ok_to_be_rude: is it ok to interrupt your users?
         '''
         self.settings = settings
         self.environment = environment
+        self.ok_to_be_rude = ok_to_be_rude
         self.mylookup = TemplateLookup(
             directories=[self.settings["package_dir"]],
             module_directory=self.settings["module_dir"])
